@@ -648,7 +648,7 @@ smcfcs.core <- function(originaldata, smtype, smformula, method, predictorMatrix
           beta <- ymod$coef
           imputations[[imp]][imputationNeeded, outcomeCol] <- 0
           outmodxb <- model.matrix(as.formula(smformula), imputations[[imp]]) %*% beta
-          prob <- expit(outmodxb[imputationNeeded])
+          prob <- plogis(outmodxb[imputationNeeded])
           imputations[[imp]][imputationNeeded, outcomeCol] <- rbinom(length(imputationNeeded), 1, prob)
         } else if (smtype == "poisson") {
           ymod <- glm(as.formula(smformula), family = "poisson", imputations[[imp]])
@@ -757,17 +757,17 @@ smcfcs.core <- function(originaldata, smtype, smformula, method, predictorMatrix
           xmod <- glm(xmodformula, family = "binomial", data = xmoddata)
           newbeta <- modPostDraw(xmod)
           if ((smtype == "casecohort") | (smtype == "nestedcc")) {
-            xfitted <- expit(model.matrix(xmodformula, data = imputations[[imp]]) %*% newbeta)
+            xfitted <- plogis(model.matrix(xmodformula, data = imputations[[imp]]) %*% newbeta)
           } else {
-            xfitted <- expit(model.matrix(xmod) %*% newbeta)
+            xfitted <- plogis(model.matrix(xmod) %*% newbeta)
           }
         } else if (method[targetCol] == "brlogreg") {
           xmod <- glm(xmodformula, family = "binomial", data = xmoddata, method = brglm2::brglmFit)
           newbeta <- modPostDraw(xmod)
           if ((smtype == "casecohort") | (smtype == "nestedcc")) {
-            xfitted <- expit(model.matrix(xmodformula, data = imputations[[imp]]) %*% newbeta)
+            xfitted <- plogis(model.matrix(xmodformula, data = imputations[[imp]]) %*% newbeta)
           } else {
-            xfitted <- expit(model.matrix(xmod) %*% newbeta)
+            xfitted <- plogis(model.matrix(xmod) %*% newbeta)
           }
         } else if (method[targetCol] == "poisson") {
           xmod <- glm(xmodformula, family = "poisson", data = xmoddata)
@@ -795,16 +795,14 @@ smcfcs.core <- function(originaldata, smtype, smformula, method, predictorMatrix
           for (j in 1:length(newcutpoints)) {
             polr_cumlogitprob[,j] <- model.matrix(xmod) %*% c(-newcutpoints[j],newbeta)
           }
-          polr_cumprobs <- cbind(rep(1,dim(imputations[[imp]])[1]),expit(polr_cumlogitprob))
+          polr_cumprobs <- cbind(rep(1,dim(imputations[[imp]])[1]),plogis(polr_cumlogitprob))
           xfitted <- cbind(-t(apply(polr_cumprobs, MARGIN=1, FUN=diff)), polr_cumprobs[,dim(polr_cumprobs)[2]])
         } else if (method[targetCol] == "mlogit") {
           if (is.factor(imputations[[imp]][, targetCol]) == FALSE) stop("Variables to be imputed using method mlogit must be stored as factors.")
           xmod <- VGAM::vglm(xmodformula, VGAM::multinomial(refLevel = 1), data = xmoddata)
-          xmod.dummy <- VGAM::vglm(xmodformula, VGAM::multinomial(refLevel = 1), data = imputations[[imp]])
           newbeta <- VGAM::coef(xmod) + MASS::mvrnorm(1, mu = rep(0, ncol(VGAM::vcov(xmod))), Sigma = VGAM::vcov(xmod))
-          linpreds <- matrix((VGAM::model.matrix(xmod.dummy)) %*% newbeta, byrow = TRUE, ncol = (nlevels(imputations[[imp]][, targetCol]) - 1))
-          denom <- 1 + rowSums(exp(linpreds))
-          xfitted <- cbind(1 / denom, exp(linpreds) / denom)
+          xmod@coefficients <- newbeta
+          xfitted <- VGAM::predictvglm(xmod, newdata = imputations[[imp]], type = "response")
         }
         if (noisy == TRUE) {
           print(summary(xmod))
@@ -1039,7 +1037,7 @@ smcfcs.core <- function(originaldata, smtype, smformula, method, predictorMatrix
               outcomeDens <- dnorm(deviation, mean = 0, sd = outcomeModResVar^0.5)
             } else if ((smtype == "logistic") | (smtype == "brlogistic")) {
               outmodxb <- model.matrix(as.formula(smformula), imputations[[imp]]) %*% outcomeModBeta
-              prob <- expit(outmodxb[imputationNeeded])
+              prob <- plogis(outmodxb[imputationNeeded])
               outcomeDens <- prob * imputations[[imp]][imputationNeeded, outcomeCol] + (1 - prob) * (1 - imputations[[imp]][imputationNeeded, outcomeCol])
             } else if (smtype == "dtsam") {
               outcomeDens <- dtsamOutcomeDens(
@@ -1137,7 +1135,7 @@ smcfcs.core <- function(originaldata, smtype, smformula, method, predictorMatrix
               reject <- 1 * (log(uDraw) > -(deviation^2) / (2 * array(outcomeModResVar, dim = c(length(imputationNeeded), 1))))
             } else if ((smtype == "logistic") | (smtype == "brlogistic")) {
               outmodxb <- model.matrix(as.formula(smformula), imputations[[imp]]) %*% outcomeModBeta
-              prob <- expit(outmodxb[imputationNeeded])
+              prob <- plogis(outmodxb[imputationNeeded])
               prob <- prob * imputations[[imp]][imputationNeeded, outcomeCol] + (1 - prob) * (1 - imputations[[imp]][imputationNeeded, outcomeCol])
               reject <- 1 * (uDraw > prob)
             } else if (smtype == "dtsam") {
@@ -1225,7 +1223,7 @@ smcfcs.core <- function(originaldata, smtype, smformula, method, predictorMatrix
               reject <- 1 * (log(uDraw) > -(deviation^2) / (2 * array(outcomeModResVar, dim = c(rjlimit, 1))))
             } else if ((smtype == "logistic") | (smtype == "brlogistic")) {
               outmodxb <- model.matrix(as.formula(smformula), tempData) %*% outcomeModBeta
-              prob <- expit(outmodxb)
+              prob <- plogis(outmodxb)
               prob <- prob * tempData[, outcomeCol] + (1 - prob) * (1 - tempData[, outcomeCol])
               reject <- 1 * (uDraw > prob)
             } else if (smtype == "dtsam") {
@@ -1327,7 +1325,7 @@ smcfcs.core <- function(originaldata, smtype, smformula, method, predictorMatrix
             }
             outcomeModBeta <- modPostDraw(ymod)
             outmodxb <- model.matrix(as.formula(smformula), imputations[[imp]]) %*% outcomeModBeta
-            prob <- expit(outmodxb[imputationNeeded])
+            prob <- plogis(outmodxb[imputationNeeded])
             imputations[[imp]][imputationNeeded, outcomeCol] <- rbinom(length(imputationNeeded), 1, prob)
           }
         }
@@ -1423,10 +1421,6 @@ updatePassiveVars <- function(data, method, passivecols) {
   data
 }
 
-expit <- function(x) {
-  exp(x) / (1 + exp(x))
-}
-
 sumna <- function(x) {
   sum(is.na(x) == FALSE)
 }
@@ -1482,7 +1476,7 @@ dtsamOutcomeDens <- function(inputData, timeEffects, outcomeModBeta, nTimePoints
   # add in covariate effects
   outmodxb <- outmodxb + matrix(covXbEffects, nrow = inputDataN, ncol = nTimePoints)
   # prob is matrix of conditional probabilities/hazard of event in each period
-  prob <- expit(outmodxb)
+  prob <- plogis(outmodxb)
   logSurvProb <- log(1 - prob)
   logSurvProbCumSum <- cbind(rep(0, inputDataN), t(apply(logSurvProb, 1, cumsum)))
 
